@@ -142,7 +142,7 @@ class KeyValueStore:
                 os.fsync(f.fileno())
         elif content_type in ['text/plain; charset=utf-8', 'application/octet-stream']:
             mode = 'w' if isinstance(value, str) else 'wb'
-            with open(file_path, mode, errors='ignore') as f:
+            with open(file_path, mode, encoding='utf-8' if mode == 'w' else None, errors='ignore') as f:
                 f.write(value)
                 f.flush()
                 os.fsync(f.fileno())
